#[non_exhaustive]pub struct BatchCreateRepositoriesRequest {
pub parent: String,
pub requests: Vec<CreateRepositoryRequest>,
/* private fields */
}Expand description
Message for creating repositoritories in batch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The connection to contain all the repositories being created. Format: projects//locations//connections/* The parent field in the CreateRepositoryRequest messages must either be empty or match this field.
requests: Vec<CreateRepositoryRequest>Required. The request messages specifying the repositories to create.
Implementations
Sourceimpl BatchCreateRepositoriesRequest
impl BatchCreateRepositoriesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_requests<T, V>(self, v: T) -> Self
pub fn set_requests<T, V>(self, v: T) -> Self