#[non_exhaustive]pub struct GitHubEnterpriseConfig {
pub host_uri: String,
pub api_key: String,
pub app_id: i64,
pub app_slug: String,
pub private_key_secret_version: String,
pub webhook_secret_secret_version: String,
pub app_installation_id: i64,
pub service_directory_config: Option<ServiceDirectoryConfig>,
pub ssl_ca: String,
pub server_version: String,
/* private fields */
}Expand description
Configuration for connections to an instance of GitHub Enterprise.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.host_uri: StringRequired. The URI of the GitHub Enterprise host this connection is for.
api_key: StringRequired. API Key used for authentication of webhook events.
app_id: i64Id of the GitHub App created from the manifest.
app_slug: StringThe URL-friendly name of the GitHub App.
private_key_secret_version: StringSecretManager resource containing the private key of the GitHub App,
formatted as projects/*/secrets/*/versions/*.
webhook_secret_secret_version: StringSecretManager resource containing the webhook secret of the GitHub App,
formatted as projects/*/secrets/*/versions/*.
app_installation_id: i64ID of the installation of the GitHub App.
service_directory_config: Option<ServiceDirectoryConfig>Configuration for using Service Directory to privately connect to a GitHub Enterprise server. This should only be set if the GitHub Enterprise server is hosted on-premises and not reachable by public internet. If this field is left empty, calls to the GitHub Enterprise server will be made over the public internet.
ssl_ca: StringSSL certificate to use for requests to GitHub Enterprise.
server_version: StringOutput only. GitHub Enterprise version installed at the host_uri.
Implementations
Sourceimpl GitHubEnterpriseConfig
impl GitHubEnterpriseConfig
Sourcepub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_api_key<T: Into<String>>(self, v: T) -> Self
pub fn set_api_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_app_id<T: Into<i64>>(self, v: T) -> Self
pub fn set_app_id<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_app_slug<T: Into<String>>(self, v: T) -> Self
pub fn set_app_slug<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_private_key_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_private_key_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of private_key_secret_version.
Example
let x = GitHubEnterpriseConfig::new().set_private_key_secret_version("example");Sourcepub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of webhook_secret_secret_version.
Example
let x = GitHubEnterpriseConfig::new().set_webhook_secret_secret_version("example");Sourcepub fn set_app_installation_id<T: Into<i64>>(self, v: T) -> Self
pub fn set_app_installation_id<T: Into<i64>>(self, v: T) -> Self
Sets the value of app_installation_id.
Example
let x = GitHubEnterpriseConfig::new().set_app_installation_id(42);Sourcepub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets the value of service_directory_config.
Example
use google_cloud_build_v2::model::ServiceDirectoryConfig;
let x = GitHubEnterpriseConfig::new().set_service_directory_config(ServiceDirectoryConfig::default()/* use setters */);Sourcepub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets or clears the value of service_directory_config.
Example
use google_cloud_build_v2::model::ServiceDirectoryConfig;
let x = GitHubEnterpriseConfig::new().set_or_clear_service_directory_config(Some(ServiceDirectoryConfig::default()/* use setters */));
let x = GitHubEnterpriseConfig::new().set_or_clear_service_directory_config(None::<ServiceDirectoryConfig>);Sourcepub fn set_ssl_ca<T: Into<String>>(self, v: T) -> Self
pub fn set_ssl_ca<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_server_version<T: Into<String>>(self, v: T) -> Self
pub fn set_server_version<T: Into<String>>(self, v: T) -> Self
Sets the value of server_version.
Example
let x = GitHubEnterpriseConfig::new().set_server_version("example");Trait Implementations
Sourceimpl Clone for GitHubEnterpriseConfig
impl Clone for GitHubEnterpriseConfig
Sourcefn clone(&self) -> GitHubEnterpriseConfig
fn clone(&self) -> GitHubEnterpriseConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GitHubEnterpriseConfig
impl Debug for GitHubEnterpriseConfig
Sourceimpl Default for GitHubEnterpriseConfig
impl Default for GitHubEnterpriseConfig
Sourcefn default() -> GitHubEnterpriseConfig
fn default() -> GitHubEnterpriseConfig
Sourceimpl Message for GitHubEnterpriseConfig
impl Message for GitHubEnterpriseConfig
Sourceimpl PartialEq for GitHubEnterpriseConfig
impl PartialEq for GitHubEnterpriseConfig
impl StructuralPartialEq for GitHubEnterpriseConfig