#[non_exhaustive]pub struct GitLabConfig {
pub host_uri: String,
pub webhook_secret_secret_version: String,
pub read_authorizer_credential: Option<UserCredential>,
pub authorizer_credential: Option<UserCredential>,
pub service_directory_config: Option<ServiceDirectoryConfig>,
pub ssl_ca: String,
pub server_version: String,
/* private fields */
}Expand description
Configuration for connections to gitlab.com or an instance of GitLab Enterprise.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.host_uri: StringThe URI of the GitLab Enterprise host this connection is for. If not specified, the default value is https://gitlab.com.
webhook_secret_secret_version: StringRequired. Immutable. SecretManager resource containing the webhook secret
of a GitLab Enterprise project, formatted as
projects/*/secrets/*/versions/*.
Required. A GitLab personal access token with the minimum read_api scope
access.
Required. A GitLab personal access token with the api scope access.
service_directory_config: Option<ServiceDirectoryConfig>Configuration for using Service Directory to privately connect to a GitLab Enterprise server. This should only be set if the GitLab Enterprise server is hosted on-premises and not reachable by public internet. If this field is left empty, calls to the GitLab Enterprise server will be made over the public internet.
ssl_ca: StringSSL certificate to use for requests to GitLab Enterprise.
server_version: StringOutput only. Version of the GitLab Enterprise server running on the
host_uri.
Implementations
Sourceimpl GitLabConfig
impl GitLabConfig
Sourcepub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of webhook_secret_secret_version.
Example
let x = GitLabConfig::new().set_webhook_secret_secret_version("example");Sets the value of read_authorizer_credential.
Example
use google_cloud_build_v2::model::UserCredential;
let x = GitLabConfig::new().set_read_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of read_authorizer_credential.
Example
use google_cloud_build_v2::model::UserCredential;
let x = GitLabConfig::new().set_or_clear_read_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = GitLabConfig::new().set_or_clear_read_authorizer_credential(None::<UserCredential>);Sets the value of authorizer_credential.
Example
use google_cloud_build_v2::model::UserCredential;
let x = GitLabConfig::new().set_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of authorizer_credential.
Example
use google_cloud_build_v2::model::UserCredential;
let x = GitLabConfig::new().set_or_clear_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = GitLabConfig::new().set_or_clear_authorizer_credential(None::<UserCredential>);Sourcepub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets the value of service_directory_config.
Example
use google_cloud_build_v2::model::ServiceDirectoryConfig;
let x = GitLabConfig::new().set_service_directory_config(ServiceDirectoryConfig::default()/* use setters */);Sourcepub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets or clears the value of service_directory_config.
Example
use google_cloud_build_v2::model::ServiceDirectoryConfig;
let x = GitLabConfig::new().set_or_clear_service_directory_config(Some(ServiceDirectoryConfig::default()/* use setters */));
let x = GitLabConfig::new().set_or_clear_service_directory_config(None::<ServiceDirectoryConfig>);Sourcepub fn set_ssl_ca<T: Into<String>>(self, v: T) -> Self
pub fn set_ssl_ca<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_server_version<T: Into<String>>(self, v: T) -> Self
pub fn set_server_version<T: Into<String>>(self, v: T) -> Self
Sets the value of server_version.
Example
let x = GitLabConfig::new().set_server_version("example");Trait Implementations
Sourceimpl Clone for GitLabConfig
impl Clone for GitLabConfig
Sourcefn clone(&self) -> GitLabConfig
fn clone(&self) -> GitLabConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GitLabConfig
impl Debug for GitLabConfig
Sourceimpl Default for GitLabConfig
impl Default for GitLabConfig
Sourcefn default() -> GitLabConfig
fn default() -> GitLabConfig
Sourceimpl Message for GitLabConfig
impl Message for GitLabConfig
Sourceimpl PartialEq for GitLabConfig
impl PartialEq for GitLabConfig
impl StructuralPartialEq for GitLabConfig