#[non_exhaustive]pub struct Repository {
pub name: String,
pub remote_uri: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub annotations: HashMap<String, String>,
pub etag: String,
pub webhook_id: String,
/* private fields */
}Expand description
A repository associated to a parent connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. Resource name of the repository, in the format
projects/*/locations/*/connections/*/repositories/*.
remote_uri: StringRequired. Git Clone HTTPS URI.
create_time: Option<Timestamp>Output only. Server assigned timestamp for when the connection was created.
update_time: Option<Timestamp>Output only. Server assigned timestamp for when the connection was updated.
annotations: HashMap<String, String>Allows clients to store small amounts of arbitrary data.
etag: StringThis checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
webhook_id: StringOutput only. External ID of the webhook created for the repository.
Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn set_remote_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_remote_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Repository::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Repository::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = Repository::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_webhook_id<T: Into<String>>(self, v: T) -> Self
pub fn set_webhook_id<T: Into<String>>(self, v: T) -> Self