UpdateConnectionRequest

Struct UpdateConnectionRequest 

#[non_exhaustive]
pub struct UpdateConnectionRequest { pub connection: Option<Connection>, pub update_mask: Option<FieldMask>, pub allow_missing: bool, pub etag: String, /* private fields */ }
Message for updating a Connection.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
connection: Option<Connection>

Required. The Connection to update.

update_mask: Option<FieldMask>

The list of fields to be updated.

allow_missing: bool

If set to true, and the connection is not found a new connection will be created. In this situation update_mask is ignored. The creation will succeed only if the input connection has all the necessary information (e.g a github_config with both user_oauth_token and installation_id properties).

etag: String

The current etag of the connection. If an etag is provided and does not match the current etag of the connection, update will be blocked and an ABORTED error will be returned.

Implementations

Source

impl UpdateConnectionRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_connection<T>(self, v: T) -> Self
where T: Into<Connection>,

Sets the value of connection.

Example
use google_cloud_build_v2::model::Connection;
let x = UpdateConnectionRequest::new().set_connection(Connection::default()/* use setters */);
pub fn set_or_clear_connection<T>(self, v: Option<T>) -> Self
where T: Into<Connection>,

Sets or clears the value of connection.

Example
use google_cloud_build_v2::model::Connection;
let x = UpdateConnectionRequest::new().set_or_clear_connection(Some(Connection::default()/* use setters */));
let x = UpdateConnectionRequest::new().set_or_clear_connection(None::<Connection>);
pub fn set_update_mask<T>(self, v: T) -> Self
where T: Into<FieldMask>,

Sets the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateConnectionRequest::new().set_update_mask(FieldMask::default()/* use setters */);
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
where T: Into<FieldMask>,

Sets or clears the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateConnectionRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateConnectionRequest::new().set_or_clear_update_mask(None::<FieldMask>);
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self

Sets the value of allow_missing.

Example
let x = UpdateConnectionRequest::new().set_allow_missing(true);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = UpdateConnectionRequest::new().set_etag("example");